# Etiketti

Label (Finnish: etiketti) some files.

[License: MPL-2.0](https://git.sr.ht/~sthagen/etiketti/tree/default/item/LICENSE) only for the pikepedf dependency - all contributions added are licensed per MIT.

Third party dependencies are documented in the folder [third-party](docs/docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![downloads](https://pepy.tech/badge/etiketti/month)](https://pepy.tech/project/etiketti)
[![wheel](https://img.shields.io/pypi/wheel/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![supported-versions](https://img.shields.io/pypi/pyversions/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)
[![supported-implementations](https://img.shields.io/pypi/implementation/etiketti.svg?style=flat)](https://pypi.python.org/pypi/etiketti/)

## Documentation

User and developer [documentation of etiketti](https://codes.dilettant.life/docs/etiketti).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of etiketti](https://todo.sr.ht/~sthagen/etiketti).

## Primary Source repository

The main source of `etiketti` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `etiketti` are:

* [on codeberg](https://codeberg.org/sthagen/etiketti) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/etiketti) - a collection of tools useful for software development.

## Status

Prototype.

**Note**: The default branch is `default`.
